# cvsdate should correspond to the cvsdate in the fedora-ds-cvs.sh script
%{!?cvsdate:%define cvsdate   20070320}

%define shortname fedora-ds

Summary:          Fedora Directory Server (base)
Name:             fedora-ds-base
Version:          1.1.0
Release:          0.1.%{?cvsdate}%{?dist}
License:          GPL plus extensions
URL:              http://directory.fedora.redhat.com/
Group:            System Environment/Daemons
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:    nspr-devel >= 4.6.4
BuildRequires:    nss-devel >= 3.11.4
BuildRequires:    svrcore-devel >= 4.0.3
BuildRequires:    mozldap-devel >= 6.0.2
BuildRequires:    db4-devel >= 4.2.52
BuildRequires:    cyrus-sasl-devel >= 2.1.19
BuildRequires:    icu >= 3.4
BuildRequires:    libicu-devel >= 3.4
# The following are needed to build the snmp ldap-agent
BuildRequires:    net-snmp-devel >= 5.1.2
%ifnarch sparc sparc64 ppc ppc64
BuildRequires:    lm_sensors-devel
%endif
BuildRequires:    bzip2-devel
BuildRequires:    zlib-devel
BuildRequires:    openssl-devel
BuildRequires:    tcp_wrappers
BuildRequires:    libselinux-devel
# the following is for the pam passthru auth plug-in
BuildRequires:    pam-devel

# for the init script
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service

Source0:          %{name}-%{version}-%{cvsdate}.tar.bz2
# fedora-ds-cvs.sh should be used to generate the source tarball from CVS
Source1:          %{name}-cvs.sh
Source2:          install.inf
Source3:          %{name}-devel.README

%description
Fedora Directory Server is an LDAPv3 compliant server.  The base package includes
the LDAP server and command line utilities for server administration.

%package          devel
Summary:          Development libraries for Fedora Directory Server
Group:            Development/Libraries
Requires:         %{name} = %{version}-%{release}

%description      devel
Development Libraries and headers for the Fedora Directory Server base package.


%prep
%setup -q -n %{name}-%{version}-%{cvsdate}
cp %{SOURCE2} install.inf
cp %{SOURCE3} README.devel

%build
%configure

# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS

%ifarch x86_64 ppc64 ia64 s390x sparc64
export USE_64=1
%endif

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT 

make DESTDIR="$RPM_BUILD_ROOT" install

mkdir -p $RPM_BUILD_ROOT/var/log/%{shortname}
mkdir -p $RPM_BUILD_ROOT/var/lib/%{shortname}
mkdir -p $RPM_BUILD_ROOT/var/lock/%{shortname}
mkdir -p $RPM_BUILD_ROOT/var/tmp/%{shortname}
mkdir -p $RPM_BUILD_ROOT%{_includedir}/%{shortname}

#remove libtool and static libs
rm -f $RPM_BUILD_ROOT%{_libdir}/%{shortname}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{shortname}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/%{shortname}/plugins/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{shortname}/plugins/*.la

install -p -m 644 ldap/servers/slapd/slapi-plugin.h $RPM_BUILD_ROOT%{_includedir}/%{shortname}/

# make sure perl scripts have a proper shebang 
sed -i -e 's|#{{PERL-EXEC}}|#!/usr/bin/perl|' $RPM_BUILD_ROOT%{_datadir}/%{shortname}/script-templates/template-*.pl
sed -i -e 's|#{{PERL-EXEC}}|#!/usr/bin/perl|' $RPM_BUILD_ROOT%{_datadir}/%{shortname}/script-templates/template-migrate*

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add %{shortname}
/sbin/ldconfig


%preun
if [ $1 = 0 ]; then
        /sbin/service %{shortname} stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del %{shortname}
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE EXCEPTION install.inf
%dir %{_sysconfdir}/%{shortname}
%dir %{_sysconfdir}/%{shortname}/schema
%config(noreplace)%{_sysconfdir}/%{shortname}/schema/*.ldif
%dir %{_sysconfdir}/%{shortname}/property
%config(noreplace)%{_sysconfdir}/%{shortname}/property/ns-slapd.properties
%dir %{_sysconfdir}/%{shortname}/config
%config(noreplace)%{_sysconfdir}/%{shortname}/config/slapd-collations.conf
%config(noreplace)%{_sysconfdir}/%{shortname}/config/certmap.conf
%{_datadir}/%{shortname}
%{_initrddir}/%{shortname}
%{_bindir}/*
%{_sbindir}/ns-slapd
%dir %{_libdir}/%{shortname}
%{_libdir}/%{shortname}/*.so.*
%dir %{_libdir}/%{shortname}/plugins
%{_libdir}/%{shortname}/plugins/*.so
%dir %{_localstatedir}/lib/%{shortname}
%dir %{_localstatedir}/log/%{shortname}
%dir %{_localstatedir}/lock/%{shortname}
%dir %{_localstatedir}/tmp/%{shortname}

%files devel
%defattr(-,root,root,-)
%doc LICENSE EXCEPTION README.devel
%{_includedir}/%{shortname}
%{_libdir}/%{shortname}/*.so

%changelog
* Tue Mar 20 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070320
- update to latest sources
- added migrateTo11 to allow migrating instances from 1.0.x to 1.1
- ldapi support
- fixed pam passthru plugin ENTRY method

* Fri Feb 23 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070223
- Renamed package to fedora-ds-base, but keep names of paths/files/services the same
- use the shortname macro (fedora-ds) for names of paths, files, and services instead
- of name, so that way we can continue to use e.g. /etc/fedora-ds instead of /etc/fedora-ds-base
- updated to latest sources

* Tue Feb 13 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070213
- More cleanup suggested by Dennis Gilmore
- This is the fedora extras candidate based on cvs tag FedoraDirSvr110a1

* Fri Feb  9 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070209
- latest sources
- added init scripts
- use /etc as instconfigdir

* Wed Feb  7 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070207
- latest sources
- moved all executables to _bindir

* Mon Jan 29 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070129
- latest sources
- added /var/tmp/fedora-ds to dirs

* Fri Jan 26 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-8.el4.20070125
- added logconv.pl
- added slapi-plugin.h to devel package
- added explicit dirs for /var/log/fedora-ds et. al.

* Thu Jan 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-7.el4.20070125
- just move all .so files into the base package from the devel package

* Thu Jan 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-6.el4.20070125
- Move the plugin *.so files into the main package instead of the devel
- package because they are loaded directly by name via dlopen

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-5.el4.20070125
- Move the script-templates directory to datadir/fedora-ds

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-4.el4.20070119
- change mozldap to mozldap6

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-3.el4.20070119
- remove . from cvsdate define

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-2.el4.20070119
- Having a problem building in Brew - may be Release format

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.cvs20070119
- Changed version to 1.1.0 and added Release 1.el4.cvs20070119
- merged in changes from Fedora Extras candidate spec file

* Mon Jan 15 2007 Rich Megginson <rmeggins@redhat.com> - 1.1-0.1.cvs20070115
- Bump component versions (nspr, nss, svrcore, mozldap) to their latest
- remove unneeded patches

* Tue Jan 09 2007 Dennis Gilmore <dennis@ausil.us> - 1.1-0.1.cvs20070108
- update to a cvs snapshot
- fedorafy the spec 
- create -devel subpackage
- apply a patch to use mozldap not mozldap6
- apply a patch to allow --prefix to work correctly

* Mon Dec 4 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-16
- Fixed the problem where the server would crash upon shutdown in dblayer
- due to a race condition among the database housekeeping threads
- Fix a problem with normalized absolute paths for db directories

* Tue Nov 28 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-15
- Touch all of the ldap/admin/src/scripts/*.in files so that they
- will be newer than their corresponding script template files, so
- that make will rebuild them.

* Mon Nov 27 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-14
- Chown new schema files when copying during instance creation

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-13
- Configure will get ldapsdk_bindir from pkg-config, or $libdir/mozldap6

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-12
- use eval to sed ./configure into ../configure

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-11
- jump through hoops to be able to run ../configure

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-10
- Need to make built dir in setup section

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-9
- The template scripts needed to use @libdir@ instead of hardcoding
- /usr/lib
- Use make DESTDIR=$RPM_BUILD_ROOT install instead of % makeinstall
- do the actual build in a "built" subdirectory, until we remove
- the old script templates

* Thu Nov 16 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-8
- Make replication plugin link with libdb

* Wed Nov 15 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-7
- Have make define LIBDIR, BINDIR, etc. for C code to use
- especially for create_instance.h

* Tue Nov 14 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-6
- Forgot to checkin new config.h.in for AC_CONFIG_HEADERS

* Tue Nov 14 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-5
- Add perldap as a Requires; update sources

* Thu Nov 9 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-4
- Fix ds_newinst.pl
- Remove obsolete #defines

* Thu Nov 9 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-3
- Update sources; rebuild to populate brew yum repo with dirsec-nss

* Tue Nov 7 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-2
- Update sources

* Thu Nov 2 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-1
- initial revision
